@@ -26,11 +26,11 @@ class FileTranslateRequest(AbstractModel):
     def __init__(self):
         r"""
         :param _Source: 源语言，支持
-zh:简体中文
+zh：简体中文
 zh-HK：繁体中文
-zh-TW : 繁体中文
-zh-TR:  繁体中文
-en ：英语
+zh-TW：繁体中文
+zh-TR：繁体中文
+en：英语
 ar：阿拉伯语
 de：德语
 es：西班牙语
@@ -40,26 +40,26 @@ ja：日语
 pt：葡萄牙语
 ru：俄语
 ko：韩语
-km：高棉语
-lo：老挝语
+th：泰语
         :type Source: str
         :param _Target: 目标语言，各源语言的目标语言支持列表如下
-zh（简体中文）： en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
-zh-HK（繁体中文） ：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
-zh-TW（繁体中文）：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
-zh-TR 繁体中文 : en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
-en （英语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、 zh-TR(繁体中文）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
-ar（阿拉伯语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-de（德语 ）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-es（西班牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-fr（法语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-it（意大利语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-ja（日语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-pt（葡萄牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-ru（俄语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-ko（韩语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-km（高棉语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
-lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+zh（简体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-HK（繁体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-TW（繁体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-TR（繁体中文）:en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+en（英语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+ar（阿拉伯语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+de（德语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+es（西班牙语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）、fr（法语）
+fr（法语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）、es（西班牙语）
+it（意大利语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ja（日语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+pt（葡萄牙语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ru（俄语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ko（韩语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+tr（土耳其语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+vi（越南语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+th（泰语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
         :type Target: str
         :param _DocumentType: 文档类型：可支持以下几种(pdf,docx,pptx,xlsx,txt,xml,html,markdown,properties)
         :type DocumentType: str
@@ -85,6 +85,24 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def Source(self):
+        """源语言，支持
+zh：简体中文
+zh-HK：繁体中文
+zh-TW：繁体中文
+zh-TR：繁体中文
+en：英语
+ar：阿拉伯语
+de：德语
+es：西班牙语
+fr：法语
+it：意大利语
+ja：日语
+pt：葡萄牙语
+ru：俄语
+ko：韩语
+th：泰语
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -93,6 +111,26 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def Target(self):
+        """目标语言，各源语言的目标语言支持列表如下
+zh（简体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-HK（繁体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-TW（繁体中文）：en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+zh-TR（繁体中文）:en（英语）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+en（英语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、ar（阿拉伯语）、de（德语）、es（西班牙语）、fr（法语）、it（意大利语）、ja（日语）、pt（葡萄牙语）、ru（俄语）、ko（韩语）、tr（土耳其语）、vi（越南语）、th（泰语）
+ar（阿拉伯语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+de（德语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+es（西班牙语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）、fr（法语）
+fr（法语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）、es（西班牙语）
+it（意大利语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ja（日语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+pt（葡萄牙语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ru（俄语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+ko（韩语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+tr（土耳其语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+vi（越南语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+th（泰语）：zh（简体中文）、zh-HK（繁体中文）、zh-TW（繁体中文）、zh-TR（繁体中文）、en（英语）
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -101,6 +139,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def DocumentType(self):
+        """文档类型：可支持以下几种(pdf,docx,pptx,xlsx,txt,xml,html,markdown,properties)
+        :rtype: str
+        """
         return self._DocumentType
 
     @DocumentType.setter
@@ -109,6 +150,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def SourceType(self):
+        """数据来源，0：url，1：直接传文件编码后数据
+        :rtype: int
+        """
         return self._SourceType
 
     @SourceType.setter
@@ -117,6 +161,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def Url(self):
+        """需要翻译文件url，URL长度不能超过1000字符。文件限制如下：docx/xIsx/html/markdown文件不超过800万字符，doc/pdf/pptx文件不超过300页，txt/po文件不超过10MB，pdf/docx/pptx/xlsx不超过40MB
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -125,6 +172,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def BasicDocumentType(self):
+        """原始文档类型。该参数为高级参数，请留空，如需使用，请与工作人员确认后再使用。
+        :rtype: str
+        """
         return self._BasicDocumentType
 
     @BasicDocumentType.setter
@@ -133,6 +183,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def CallbackUrl(self):
+        """回调url，URL长度不能超过256字符。文件大于10MB或字符较多时，建议采用回调方式；回调时，所有内容会放入 Body 中，具体请参见[文件翻译回调说明](https://cloud.tencent.com/document/product/551/91138)。
+        :rtype: str
+        """
         return self._CallbackUrl
 
     @CallbackUrl.setter
@@ -141,6 +194,9 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
 
     @property
     def Data(self):
+        """文件数据，当SourceType 值为1时必须填写，为0可不写。要base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。数据要小于5MB。
+        :rtype: str
+        """
         return self._Data
 
     @Data.setter
@@ -184,6 +240,9 @@ class FileTranslateResponse(AbstractModel):
 
     @property
     def Data(self):
+        """文件翻译的请求返回结果，包含结果查询需要的TaskId
+        :rtype: :class:`tencentcloud.tmt.v20180321.models.Task`
+        """
         return self._Data
 
     @Data.setter
@@ -192,6 +251,9 @@ class FileTranslateResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -207,7 +269,7 @@ class FileTranslateResponse(AbstractModel):
 
 
 class GetFileTranslateData(AbstractModel):
-    """查询文件翻译任务
+    """文件翻译任务结果
 
     """
 
@@ -215,25 +277,36 @@ class GetFileTranslateData(AbstractModel):
         r"""
         :param _TaskId: 任务ID
         :type TaskId: str
-        :param _Status: 状态
+        :param _Status: 任务状态
+
+- init：任务已初始化
+- wait：任务等待执行
+- success：任务执行成功
+- fail：任务执行失败
         :type Status: str
-        :param _FileData: 文件数据
+        :param _FileData: 文件数据，目标文件必须小于50M，否则请通过回调方式请求文件翻译接口
 注意：此字段可能返回 null，表示取不到有效值。
         :type FileData: str
         :param _Message: 错误提示
 注意：此字段可能返回 null，表示取不到有效值。
         :type Message: str
-        :param _Progress: 翻译进度
+        :param _Progress: 任务进度
         :type Progress: int
+        :param _UsedAmount: 本次翻译消耗的字符数	
+        :type UsedAmount: int
         """
         self._TaskId = None
         self._Status = None
         self._FileData = None
         self._Message = None
         self._Progress = None
+        self._UsedAmount = None
 
     @property
     def TaskId(self):
+        """任务ID
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -242,6 +315,14 @@ class GetFileTranslateData(AbstractModel):
 
     @property
     def Status(self):
+        """任务状态
+
+- init：任务已初始化
+- wait：任务等待执行
+- success：任务执行成功
+- fail：任务执行失败
+        :rtype: str
+        """
         return self._Status
 
     @Status.setter
@@ -250,6 +331,10 @@ class GetFileTranslateData(AbstractModel):
 
     @property
     def FileData(self):
+        """文件数据，目标文件必须小于50M，否则请通过回调方式请求文件翻译接口
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._FileData
 
     @FileData.setter
@@ -258,6 +343,10 @@ class GetFileTranslateData(AbstractModel):
 
     @property
     def Message(self):
+        """错误提示
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Message
 
     @Message.setter
@@ -266,12 +355,26 @@ class GetFileTranslateData(AbstractModel):
 
     @property
     def Progress(self):
+        """任务进度
+        :rtype: int
+        """
         return self._Progress
 
     @Progress.setter
     def Progress(self, Progress):
         self._Progress = Progress
 
+    @property
+    def UsedAmount(self):
+        """本次翻译消耗的字符数	
+        :rtype: int
+        """
+        return self._UsedAmount
+
+    @UsedAmount.setter
+    def UsedAmount(self, UsedAmount):
+        self._UsedAmount = UsedAmount
+
 
     def _deserialize(self, params):
         self._TaskId = params.get("TaskId")
@@ -279,6 +382,7 @@ class GetFileTranslateData(AbstractModel):
         self._FileData = params.get("FileData")
         self._Message = params.get("Message")
         self._Progress = params.get("Progress")
+        self._UsedAmount = params.get("UsedAmount")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -303,6 +407,9 @@ class GetFileTranslateRequest(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务ID
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -339,6 +446,9 @@ class GetFileTranslateResponse(AbstractModel):
 
     @property
     def Data(self):
+        """任务id
+        :rtype: :class:`tencentcloud.tmt.v20180321.models.GetFileTranslateData`
+        """
         return self._Data
 
     @Data.setter
@@ -347,6 +457,9 @@ class GetFileTranslateResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -375,6 +488,9 @@ class ImageRecord(AbstractModel):
 
     @property
     def Value(self):
+        """图片翻译结果
+        :rtype: list of ItemValue
+        """
         return self._Value
 
     @Value.setter
@@ -442,6 +558,9 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def SessionUuid(self):
+        """唯一id，返回时原样返回
+        :rtype: str
+        """
         return self._SessionUuid
 
     @SessionUuid.setter
@@ -450,6 +569,9 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def Scene(self):
+        """doc:文档扫描
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -458,6 +580,9 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def Data(self):
+        """图片数据的Base64字符串，经Base64编码后不超过 7M，分辨率建议600*800以上，支持PNG、JPG、JPEG、BMP、PDF格式。图片中包含文字需要少于6000字符。
+        :rtype: str
+        """
         return self._Data
 
     @Data.setter
@@ -466,6 +591,9 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def Source(self):
+        """源语言，支持语言列表：<li> auto：自动识别（识别为一种语言）</li> <li>zh：简体中文</li> <li>zh-TW：繁体中文</li> <li>en：英语</li> <li>ja：日语</li> <li>ko：韩语</li> <li>ru：俄语</li> <li>fr：法语</li> <li>de：德语</li> <li>it：意大利语</li> <li>es：西班牙语</li> <li>pt：葡萄牙语</li> <li>ms：马来西亚语</li> <li>th：泰语</li><li>vi：越南语</li>
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -474,6 +602,23 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def Target(self):
+        """目标语言，各源语言的目标语言支持列表如下：
+<li>zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
+<li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
+<li>en（英语）：zh（中文）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
+<li>ja（日语）：zh（中文）、en（英语）、ko（韩语）</li>
+<li>ko（韩语）：zh（中文）、en（英语）、ja（日语）</li>
+<li>ru：俄语：zh（中文）、en（英语）</li>
+<li>fr：法语：zh（中文）、en（英语）</li>
+<li>de：德语：zh（中文）、en（英语）</li>
+<li>it：意大利语：zh（中文）、en（英语）</li>
+<li>es：西班牙语：zh（中文）、en（英语）</li>
+<li>pt：葡萄牙语：zh（中文）、en（英语）</li>
+<li>ms：马来西亚语：zh（中文）、en（英语）</li>
+<li>th：泰语：zh（中文）、en（英语）</li>
+<li>vi：越南语：zh（中文）、en（英语）</li>
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -482,6 +627,9 @@ class ImageTranslateRequest(AbstractModel):
 
     @property
     def ProjectId(self):
+        """项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -532,6 +680,9 @@ class ImageTranslateResponse(AbstractModel):
 
     @property
     def SessionUuid(self):
+        """请求的SessionUuid返回
+        :rtype: str
+        """
         return self._SessionUuid
 
     @SessionUuid.setter
@@ -540,6 +691,9 @@ class ImageTranslateResponse(AbstractModel):
 
     @property
     def Source(self):
+        """源语言
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -548,6 +702,9 @@ class ImageTranslateResponse(AbstractModel):
 
     @property
     def Target(self):
+        """目标语言
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -556,6 +713,9 @@ class ImageTranslateResponse(AbstractModel):
 
     @property
     def ImageRecord(self):
+        """图片翻译结果，翻译结果按识别的文本每一行独立翻译，后续会推出按段落划分并翻译的版本
+        :rtype: :class:`tencentcloud.tmt.v20180321.models.ImageRecord`
+        """
         return self._ImageRecord
 
     @ImageRecord.setter
@@ -564,6 +724,9 @@ class ImageTranslateResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -610,6 +773,9 @@ class ItemValue(AbstractModel):
 
     @property
     def SourceText(self):
+        """识别出的源文
+        :rtype: str
+        """
         return self._SourceText
 
     @SourceText.setter
@@ -618,6 +784,9 @@ class ItemValue(AbstractModel):
 
     @property
     def TargetText(self):
+        """翻译后的译文
+        :rtype: str
+        """
         return self._TargetText
 
     @TargetText.setter
@@ -626,6 +795,9 @@ class ItemValue(AbstractModel):
 
     @property
     def X(self):
+        """X坐标
+        :rtype: int
+        """
         return self._X
 
     @X.setter
@@ -634,6 +806,9 @@ class ItemValue(AbstractModel):
 
     @property
     def Y(self):
+        """Y坐标
+        :rtype: int
+        """
         return self._Y
 
     @Y.setter
@@ -642,6 +817,9 @@ class ItemValue(AbstractModel):
 
     @property
     def W(self):
+        """宽度
+        :rtype: int
+        """
         return self._W
 
     @W.setter
@@ -650,6 +828,9 @@ class ItemValue(AbstractModel):
 
     @property
     def H(self):
+        """高度
+        :rtype: int
+        """
         return self._H
 
     @H.setter
@@ -691,6 +872,9 @@ class LanguageDetectRequest(AbstractModel):
 
     @property
     def Text(self):
+        """待识别的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败。单次请求的文本长度需要低于2000。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -699,6 +883,9 @@ class LanguageDetectRequest(AbstractModel):
 
     @property
     def ProjectId(self):
+        """项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -737,6 +924,10 @@ class LanguageDetectResponse(AbstractModel):
 
     @property
     def Lang(self):
+        """识别出的语言种类，参考语言列表
+<li> zh : 中文 </li> <li> en : 英文 </li><li> jp : 日语 </li> <li> kr : 韩语 </li><li> de : 德语 </li><li> fr : 法语 </li><li> es : 西班牙文 </li> <li> it : 意大利文 </li><li> tr : 土耳其文 </li><li> ru : 俄文 </li><li> pt : 葡萄牙文 </li><li> vi : 越南文 </li><li> id : 印度尼西亚文 </li><li> ms : 马来西亚文 </li><li> th : 泰文 </li>
+        :rtype: str
+        """
         return self._Lang
 
     @Lang.setter
@@ -745,6 +936,9 @@ class LanguageDetectResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -798,6 +992,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def SessionUuid(self):
+        """一段完整的语音对应一个SessionUuid
+        :rtype: str
+        """
         return self._SessionUuid
 
     @SessionUuid.setter
@@ -806,6 +1003,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def Source(self):
+        """音频中的语言类型，支持语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -814,6 +1014,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def Target(self):
+        """翻译目标语言类型，支持的语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -822,6 +1025,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def AudioFormat(self):
+        """pcm : 146   speex : 16779154   mp3 : 83886080
+        :rtype: int
+        """
         return self._AudioFormat
 
     @AudioFormat.setter
@@ -830,6 +1036,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def Seq(self):
+        """语音分片的序号，从0开始
+        :rtype: int
+        """
         return self._Seq
 
     @Seq.setter
@@ -838,6 +1047,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def IsEnd(self):
+        """是否最后一片语音分片，0-否，1-是
+        :rtype: int
+        """
         return self._IsEnd
 
     @IsEnd.setter
@@ -846,6 +1058,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def Data(self):
+        """语音分片内容进行 Base64 编码后的字符串。音频内容需包含有效并可识别的文本信息。
+        :rtype: str
+        """
         return self._Data
 
     @Data.setter
@@ -854,6 +1069,9 @@ class SpeechTranslateRequest(AbstractModel):
 
     @property
     def ProjectId(self):
+        """项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -864,6 +1082,9 @@ class SpeechTranslateRequest(AbstractModel):
     def Mode(self):
         warnings.warn("parameter `Mode` is deprecated", DeprecationWarning) 
 
+        """识别模式，该参数已废弃
+        :rtype: str
+        """
         return self._Mode
 
     @Mode.setter
@@ -876,6 +1097,9 @@ class SpeechTranslateRequest(AbstractModel):
     def TransType(self):
         warnings.warn("parameter `TransType` is deprecated", DeprecationWarning) 
 
+        """该参数已废弃
+        :rtype: int
+        """
         return self._TransType
 
     @TransType.setter
@@ -944,6 +1168,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def SessionUuid(self):
+        """请求的SessionUuid直接返回
+        :rtype: str
+        """
         return self._SessionUuid
 
     @SessionUuid.setter
@@ -952,6 +1179,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def RecognizeStatus(self):
+        """语音识别状态 1-进行中 0-完成
+        :rtype: int
+        """
         return self._RecognizeStatus
 
     @RecognizeStatus.setter
@@ -960,6 +1190,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def SourceText(self):
+        """识别出的原文
+        :rtype: str
+        """
         return self._SourceText
 
     @SourceText.setter
@@ -968,6 +1201,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def TargetText(self):
+        """翻译出的译文
+        :rtype: str
+        """
         return self._TargetText
 
     @TargetText.setter
@@ -976,6 +1212,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def Seq(self):
+        """第几个语音分片
+        :rtype: int
+        """
         return self._Seq
 
     @Seq.setter
@@ -984,6 +1223,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def Source(self):
+        """原语言
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -992,6 +1234,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def Target(self):
+        """目标语言
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -1000,6 +1245,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def VadSeq(self):
+        """当请求的Mode参数填写bvad是，启动VadSeq。此时Seq会被设置为后台vad（静音检测）后的新序号，而VadSeq代表客户端原始Seq值
+        :rtype: int
+        """
         return self._VadSeq
 
     @VadSeq.setter
@@ -1008,6 +1256,9 @@ class SpeechTranslateResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1041,6 +1292,9 @@ class Task(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务ID，可通过此ID在轮询接口获取识别状态与结果。注意：TaskId数据类型为字符串类型
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -1127,6 +1381,28 @@ hi：印地语
 
     @property
     def Source(self):
+        """源语言，支持： 
+auto：自动识别（识别为一种语言）
+zh：简体中文
+zh-TW：繁体中文
+en：英语
+ja：日语
+ko：韩语
+fr：法语
+es：西班牙语
+it：意大利语
+de：德语
+tr：土耳其语
+ru：俄语
+pt：葡萄牙语
+vi：越南语
+id：印尼语
+th：泰语
+ms：马来西亚语
+ar：阿拉伯语
+hi：印地语
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -1135,6 +1411,28 @@ hi：印地语
 
     @property
     def Target(self):
+        """目标语言，各源语言的目标语言支持列表如下
+
+<li> zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）</li>
+<li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）</li>
+<li>en（英语）：zh（中文）、zh-TW（繁体中文）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）、hi（印地语）</li>
+<li>ja（日语）：zh（中文）、zh-TW（繁体中文）、en（英语）、ko（韩语）</li>
+<li>ko（韩语）：zh（中文）、zh-TW（繁体中文）、en（英语）、ja（日语）</li>
+<li>fr（法语）：zh（中文）、zh-TW（繁体中文）、en（英语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>es（西班牙语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>it（意大利语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>de（德语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>tr（土耳其语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>ru（俄语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、pt（葡萄牙语）</li>
+<li>pt（葡萄牙语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）</li>
+<li>vi（越南语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>id（印尼语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>th（泰语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>ms（马来语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>ar（阿拉伯语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>hi（印地语）：en（英语）</li>
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -1143,6 +1441,9 @@ hi：印地语
 
     @property
     def ProjectId(self):
+        """项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -1151,6 +1452,9 @@ hi：印地语
 
     @property
     def SourceTextList(self):
+        """待翻译的文本列表，批量接口可以以数组方式在一次请求中填写多个待翻译文本。文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度总和需要低于6000字符。
+        :rtype: list of str
+        """
         return self._SourceTextList
 
     @SourceTextList.setter
@@ -1159,6 +1463,9 @@ hi：印地语
 
     @property
     def TermRepoIDList(self):
+        """需要使用的术语库列表
+        :rtype: list of str
+        """
         return self._TermRepoIDList
 
     @TermRepoIDList.setter
@@ -1167,6 +1474,9 @@ hi：印地语
 
     @property
     def SentRepoIDList(self):
+        """需要使用的例句库列表
+        :rtype: list of str
+        """
         return self._SentRepoIDList
 
     @SentRepoIDList.setter
@@ -1204,16 +1514,22 @@ class TextTranslateBatchResponse(AbstractModel):
         :type Target: str
         :param _TargetTextList: 翻译后的文本列表
         :type TargetTextList: list of str
+        :param _UsedAmount: 本次翻译消耗的字符数
+        :type UsedAmount: int
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Source = None
         self._Target = None
         self._TargetTextList = None
+        self._UsedAmount = None
         self._RequestId = None
 
     @property
     def Source(self):
+        """源语言，详见入参Source
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -1222,6 +1538,9 @@ class TextTranslateBatchResponse(AbstractModel):
 
     @property
     def Target(self):
+        """目标语言，详见入参Target
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -1230,14 +1549,31 @@ class TextTranslateBatchResponse(AbstractModel):
 
     @property
     def TargetTextList(self):
+        """翻译后的文本列表
+        :rtype: list of str
+        """
         return self._TargetTextList
 
     @TargetTextList.setter
     def TargetTextList(self, TargetTextList):
         self._TargetTextList = TargetTextList
 
+    @property
+    def UsedAmount(self):
+        """本次翻译消耗的字符数
+        :rtype: int
+        """
+        return self._UsedAmount
+
+    @UsedAmount.setter
+    def UsedAmount(self, UsedAmount):
+        self._UsedAmount = UsedAmount
+
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1249,6 +1585,7 @@ class TextTranslateBatchResponse(AbstractModel):
         self._Source = params.get("Source")
         self._Target = params.get("Target")
         self._TargetTextList = params.get("TargetTextList")
+        self._UsedAmount = params.get("UsedAmount")
         self._RequestId = params.get("RequestId")
 
 
@@ -1322,6 +1659,9 @@ hi：印地语
 
     @property
     def SourceText(self):
+        """待翻译的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度需要低于6000字符。
+        :rtype: str
+        """
         return self._SourceText
 
     @SourceText.setter
@@ -1330,6 +1670,28 @@ hi：印地语
 
     @property
     def Source(self):
+        """源语言，支持：
+auto：自动识别（识别为一种语言）
+zh：简体中文
+zh-TW：繁体中文
+en：英语
+ja：日语
+ko：韩语
+fr：法语
+es：西班牙语
+it：意大利语
+de：德语
+tr：土耳其语
+ru：俄语
+pt：葡萄牙语
+vi：越南语
+id：印尼语
+th：泰语
+ms：马来西亚语
+ar：阿拉伯语
+hi：印地语
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -1338,6 +1700,28 @@ hi：印地语
 
     @property
     def Target(self):
+        """目标语言，各源语言的目标语言支持列表如下
+
+<li> zh（简体中文）：zh-TW（繁体中文）、en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）</li>
+<li>zh-TW（繁体中文）：zh（简体中文）、en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）</li>
+<li>en（英语）：zh（中文）、zh-TW（繁体中文）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）、hi（印地语）</li>
+<li>ja（日语）：zh（中文）、zh-TW（繁体中文）、en（英语）、ko（韩语）</li>
+<li>ko（韩语）：zh（中文）、zh-TW（繁体中文）、en（英语）、ja（日语）</li>
+<li>fr（法语）：zh（中文）、zh-TW（繁体中文）、en（英语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>es（西班牙语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>it（意大利语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>de（德语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>tr（土耳其语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、ru（俄语）、pt（葡萄牙语）</li>
+<li>ru（俄语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、pt（葡萄牙语）</li>
+<li>pt（葡萄牙语）：zh（中文）、zh-TW（繁体中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）</li>
+<li>vi（越南语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>id（印尼语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>th（泰语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>ms（马来语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>ar（阿拉伯语）：zh（中文）、zh-TW（繁体中文）、en（英语）</li>
+<li>hi（印地语）：en（英语）</li>
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
@@ -1346,6 +1730,9 @@ hi：印地语
 
     @property
     def ProjectId(self):
+        """项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -1354,6 +1741,9 @@ hi：印地语
 
     @property
     def UntranslatedText(self):
+        """用来标记不希望被翻译的文本内容，如句子中的特殊符号、人名、地名等；每次请求只支持配置一个不被翻译的单词；仅支持配置人名、地名等名词，不要配置动词或短语，否则会影响翻译结果。
+        :rtype: str
+        """
         return self._UntranslatedText
 
     @UntranslatedText.setter
@@ -1362,6 +1752,9 @@ hi：印地语
 
     @property
     def TermRepoIDList(self):
+        """需要使用的术语库列表
+        :rtype: list of str
+        """
         return self._TermRepoIDList
 
     @TermRepoIDList.setter
@@ -1370,6 +1763,9 @@ hi：印地语
 
     @property
     def SentRepoIDList(self):
+        """需要使用的例句库列表
+        :rtype: list of str
+        """
         return self._SentRepoIDList
 
     @SentRepoIDList.setter
@@ -1408,16 +1804,22 @@ class TextTranslateResponse(AbstractModel):
         :type Source: str
         :param _Target: 目标语言，详见入参Target
         :type Target: str
+        :param _UsedAmount: 本次翻译消耗的字符数
+        :type UsedAmount: int
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._TargetText = None
         self._Source = None
         self._Target = None
+        self._UsedAmount = None
         self._RequestId = None
 
     @property
     def TargetText(self):
+        """翻译后的文本
+        :rtype: str
+        """
         return self._TargetText
 
     @TargetText.setter
@@ -1426,6 +1828,9 @@ class TextTranslateResponse(AbstractModel):
 
     @property
     def Source(self):
+        """源语言，详见入参Source
+        :rtype: str
+        """
         return self._Source
 
     @Source.setter
@@ -1434,14 +1839,31 @@ class TextTranslateResponse(AbstractModel):
 
     @property
     def Target(self):
+        """目标语言，详见入参Target
+        :rtype: str
+        """
         return self._Target
 
     @Target.setter
     def Target(self, Target):
         self._Target = Target
 
+    @property
+    def UsedAmount(self):
+        """本次翻译消耗的字符数
+        :rtype: int
+        """
+        return self._UsedAmount
+
+    @UsedAmount.setter
+    def UsedAmount(self, UsedAmount):
+        self._UsedAmount = UsedAmount
+
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1453,4 +1875,5 @@ class TextTranslateResponse(AbstractModel):
         self._TargetText = params.get("TargetText")
         self._Source = params.get("Source")
         self._Target = params.get("Target")
+        self._UsedAmount = params.get("UsedAmount")
         self._RequestId = params.get("RequestId")
\ No newline at end of file
